#
# spec file for package ghc
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?suse_version} == 1315 && !0%{?is_opensuse}
%define without_manual 1
%endif

%global unregisterised_archs s390 s390x

Name:           ghc
Version:        8.2.2
Release:        10.20
Url:            http://haskell.org/ghc/dist/%{version}/%{name}-%{version}-src.tar.xz
Summary:        The Glorious Glasgow Haskell Compiler
License:        BSD-3-Clause
Group:          Development/Languages/Other
ExclusiveArch:  aarch64 %{arm} %{ix86} x86_64 ppc64 ppc64le s390x
# hard to port to PIE, some prebuilt static libraries are non-PIC ...
#!BuildIgnore:  gcc-PIE
BuildRequires:  binutils-devel
BuildRequires:  gcc
BuildRequires:  ghc-bootstrap >= 7.8
BuildRequires:  ghc-rpm-macros-extra
BuildRequires:  glibc-devel
BuildRequires:  gmp-devel
BuildRequires:  libdw-devel
BuildRequires:  libelf-devel
#Fix for openSUSE:Leap:42.1
%if 0%{?suse_version} == 1315
BuildRequires:  libffi48-devel
%else
BuildRequires:  libffi-devel
%endif
%ifarch aarch64 %{arm}
BuildRequires:  binutils-gold
%endif
%ifarch aarch64 %{arm} %{ix86} x86_64
BuildRequires:  llvm-devel
%endif
BuildRequires:  ncurses-devel
BuildRequires:  pkg-config
BuildRequires:  xz
%if %{undefined without_manual}
BuildRequires:  python-sphinx
%endif

PreReq:         update-alternatives
Requires:       ghc-compiler = %{version}-%{release}
Requires:       ghc-ghc-devel = %{version}-%{release}
Requires:       ghc-libraries = %{version}-%{release}
Source:         http://haskell.org/ghc/dist/%{version}/%{name}-%{version}-src.tar.xz
Source1:        ghc-rpmlintrc
# PATCH-FIX-UPSTREAM 0001-PPC-CodeGen-fix-lwa-instruction-generation.patch peter.trommler@ohm-hochschule.de -- Fix PPC codegen: Fixes ghc-zeromq4-haskell build on 64-bit PowerPCs
Patch30:        0001-PPC-CodeGen-fix-lwa-instruction-generation.patch
# PATCH-FIX-UPSTREAM 0001-PPC-Implement-Atomic-operations.patch ptrommler@icloud.com -- Inline atomic operations for PowerPC.
Patch32:        0001-PPC-Implement-Atomic-operations.patch
# PATCH-FIX-UPSTREAM 0001-Use-__atomic-intrinsics-for-atomicread-write.patch ptrommler@icloud.com -- Fix atomic read and atomic write on platforms that have no native code generator nor LLVM backend. This is s390x for openSUSE. See Haskell Trac #14244.
Patch33:        0001-Use-__atomic-intrinsics-for-atomicread-write.patch
# PATCH-FIX-UPSTREAM D4089.patch ptrommler@icloud.com -- Fix GHCi on ppc64. See Haskell Trac #11262
Patch34:        D4089.patch
# PATCH-FIX-UPSTREAM ghc-pie.patch - set linux as default PIE platform
Patch35:        ghc-pie.patch
# PATCH-FIX-OPENSUSE ghc-8.0.2-Cabal-dynlibdir.patch -- Fix shared library directory location.
Patch100:       ghc-8.0.2-Cabal-dynlibdir.patch
# PATCH-FIX-UPSTREAM buildpath-abi-stability.patch -- debian patch for more stable abi-1
Patch110:       buildpath-abi-stability.patch
# PATCH-FIX-UPSTREAM reproducible-tmp-names.patch -- debian patch for more stable abi-2
Patch111:       reproducible-tmp-names.patch

%description
Haskell is the standard purely functional programming language; the
current language version is Haskell 98, agreed in December 1998.

GHC is a state-of-the-art programming suite for Haskell.  Included is
an optimising compiler generating good code for a variety of
platforms, together with an interactive system for convenient, quick
development.  The distribution includes space and time profiling
facilities, a large collection of libraries, and support for various
language extensions, including concurrency, exceptions, and foreign
language interfaces (C, C++, etc).

A wide variety of Haskell related resources (tutorials, libraries,
specifications, documentation, compilers, interprbeters, references,
contact information, links to research groups) are available from the
Haskell home page at <http://www.haskell.org/>.

%package compiler
Summary:        GHC compiler and utilities
Group:          Development/Languages/Other
Requires:       gcc
Requires:       ghc-base-devel
Requires(post): update-alternatives
Requires(postun): update-alternatives
%ifarch aarch64 %{arm}
Requires:       binutils-gold
%endif
%ifarch aarch64 %{arm} %{ix86} x86_64
# Leap:15 + SLE15 now have wrong metapackage
%if 0%{?suse_version} >= 1550 || 0%{?suse_version} == 1315
Requires:       llvm
%else
Requires:       llvm5
%endif
%endif

%description compiler
This package contains the GHC compiler, tools and utilities.

The GHC libraries are provided by ghc-devel.
To install all of GHC install package ghc.

%global ghc_version_override %{version}

%global ghc_pkg_c_deps ghc-compiler = %{ghc_version_override}-%{release}

%if %{defined ghclibdir}
%ghc_lib_subpackage -d Cabal-2.0.1.0
%ghc_lib_subpackage -d array-0.5.2.0
%ghc_lib_subpackage -d -c gmp-devel,libffi-devel,libdw-devel,libelf-devel base-4.10.1.0
%ghc_lib_subpackage -d binary-0.8.5.1
%ghc_lib_subpackage -d bytestring-0.10.8.2
%ghc_lib_subpackage -d containers-0.5.10.2
%ghc_lib_subpackage -d deepseq-1.4.3.0
%ghc_lib_subpackage -d directory-1.3.0.2
%ghc_lib_subpackage -d filepath-1.4.1.2
%ghc_lib_subpackage -d -x ghc-%{ghc_version_override}
%ghc_lib_subpackage -d ghc-boot-%{ghc_version_override}
%ghc_lib_subpackage -d ghc-boot-th-%{ghc_version_override}
%ghc_lib_subpackage -d ghc-compact-0.1.0.0
%ghc_lib_subpackage -d -x ghci-%{ghc_version_override}
%ghc_lib_subpackage -d haskeline-0.7.4.0
%ghc_lib_subpackage -d hoopl-3.10.2.2
%ghc_lib_subpackage -d hpc-0.6.0.3
%ghc_lib_subpackage -d pretty-1.1.3.3
%ghc_lib_subpackage -d process-1.6.1.0
%ghc_lib_subpackage -d template-haskell-2.12.0.0
%ghc_lib_subpackage -d -c ncurses-devel terminfo-0.4.1.0
%ghc_lib_subpackage -d time-1.8.0.2
%ghc_lib_subpackage -d transformers-0.5.2.0
%ghc_lib_subpackage -d unix-2.7.2.2
%ghc_lib_subpackage -d xhtml-3000.2.2
%endif

%global version %{ghc_version_override}

%package libraries
Summary:        GHC development libraries meta package
Group:          Development/Libraries/Other
Requires:       ghc-compiler = %{version}-%{release}
Obsoletes:      ghc-devel < %{version}-%{release}
Provides:       ghc-devel = %{version}-%{release}
Obsoletes:      ghc-prof < %{version}-%{release}
Provides:       ghc-prof = %{version}-%{release}
%{?ghc_packages_list:Requires: %(echo %{ghc_packages_list} | sed -e "s/\([^ ]*\)-\([^ ]*\)/ghc-\1-devel = \2-%{release},/g")}

%description libraries
This is a meta-package for all the development library packages in GHC
except the ghc library, which is installed by the toplevel ghc metapackage.

%prep
%setup -q
%patch30 -p1
%patch32 -p1
%patch33 -p1
%patch34 -p1
%patch35 -p1
%patch100 -p1
%patch110 -p1
%patch111 -p1

%build
# Check if bootstrap is required, i.e. version is different from ghc's version
# Note: Cannot use ghc_version macro here as we defined version override earlier
%if "%version" != "%(ghc --numeric-version)"
%define ghc_boot 1
cat > mk/build.mk <<EOF
GhcLibWays = v %{!?ghc_without_shared:dyn}
%if %{defined ghc_without_shared}
DYNAMIC_BY_DEFAULT   = NO
DYNAMIC_GHC_PROGRAMS = NO
%endif
%ifarch %{unregisterised_archs}
GhcUnregisterised    = YES
GhcWithNativeCodeGen = NO
GhcWithInterpreter   = YES
SRC_HC_OPTS          = -O -H64m
GhcStage1HcOpts      = -O
GhcStage2HcOpts      = -O
GhcHcOpts            = -Rghc-timing
GhcLibHcOpts         = -O
SRC_HC_OPTS         += -optc-fno-builtin
SRC_CC_OPTS         += -fno-builtin
SRC_HC_OPTS         += -optc-Wno-return-type
SRC_CC_OPTS         += -Wno-return-type
%endif
HADDOCK_DOCS         = NO
BUILD_SPHINX_HTML    = NO
BUILD_SPHINX_PS      = NO
BUILD_SPHINX_PDF     = NO
HSCOLOUR_SRCS        = NO
EOF
./configure --prefix=%{_builddir}/ghc-boot --with-system-libffi
%ifnarch aarch64 %{arm} s390 s390x
make %{?_smp_mflags}
%else
make -j 2
%endif
make install
make clean
%endif

cat > mk/build.mk <<EOF
%ifarch aarch64 %{arm}
BuildFlavour = perf-llvm
%else
BuildFlavour = perf
%endif
EOF

# BuildFlavours are defined in mk/build.mk.sample
cat mk/build.mk.sample >> mk/build.mk
# override some settings
cat >> mk/build.mk << EOF
GhcLibWays = v %{!?ghc_without_shared:dyn} %{!?without_prof:p}
%if %{defined ghc_without_shared}
DYNAMIC_BY_DEFAULT   = NO
DYNAMIC_GHC_PROGRAMS = NO
%endif
%ifarch  %{unregisterised_archs}
GhcUnregisterised    = YES
GhcWithNativeCodeGen = NO
SRC_HC_OPTS          = -O -H64m
GhcStage1HcOpts      = -O
GhcStage2HcOpts      = -O
GhcHcOpts            = -Rghc-timing
GhcLibHcOpts         = -O
SRC_HC_OPTS         += -optc-fno-builtin -optc-Wno-return-type
SRC_CC_OPTS         += -fno-builtin -Wno-return-type
%endif
%if %{defined without_haddock}
HADDOCK_DOCS = NO
%endif
BUILD_SPHINX_PS   = NO
%if %{defined without_manual}
BUILD_SPHINX_HTML = NO
BUILD_SPHINX_PDF  = NO
%endif
%if %{defined without_hscolour}
HSCOLOUR_SRCS = NO
%endif
EOF

export CFLAGS="${CFLAGS:-%optflags}"
./configure --prefix=%{_prefix} --exec-prefix=%{_exec_prefix} \
  --bindir=%{_bindir} --sbindir=%{_sbindir} --sysconfdir=%{_sysconfdir} \
  --datadir=%{_datadir} --includedir=%{_includedir} --libdir=%{_libdir} \
  --libexecdir=%{_libexecdir} --localstatedir=%{_localstatedir} \
  --sharedstatedir=%{_sharedstatedir} --mandir=%{_mandir} \
  %{?ghc_boot:--with-ghc=%{_builddir}/ghc-boot/bin/ghc} \
  --with-system-libffi 

%ifnarch aarch64 %{arm} s390 s390x
make %{?_smp_mflags}
%else
make -j 2
%endif

%install
%makeinstall

for i in %{ghc_packages_list}; do
name=$(echo $i | sed -e "s/\(.*\)-.*/\1/")
ver=$(echo $i | sed -e "s/.*-\(.*\)/\1/")
%ghc_gen_filelists $name $ver
echo "%doc libraries/$name/LICENSE" >> ghc-$name.files
done

# ghc-base should own ghclibdir
echo "%dir %{ghclibdir}" >> ghc-base.files

%ghc_gen_filelists ghc %{ghc_version_override}
%ghc_gen_filelists ghci %{ghc_version_override}
%ghc_gen_filelists ghc-prim 0.5.1.1
%ghc_gen_filelists integer-gmp 1.0.1.0

%define merge_filelist()\
cat ghc-%1.files >> ghc-%2.files\
cat ghc-%1-devel.files >> ghc-%2-devel.files\
cp -p libraries/%1/LICENSE libraries/LICENSE.%1\
echo "%doc libraries/LICENSE.%1" >> ghc-%2.files

%merge_filelist integer-gmp base
%merge_filelist ghc-prim base

%if %{undefined ghc_without_shared}
echo %%dir %{ghclibdir}/rts >> ghc-base.files
ls %{buildroot}%{ghclibdir}/rts/libHS*.so >> ghc-base.files
sed -i -e "s|^%{buildroot}||g" ghc-base.files
%endif
echo %%dir %{ghclibdir}/rts >> ghc-base-devel.files
ls -d %{buildroot}%{ghclibdir}/rts/libHS*.a  %{buildroot}%{ghclibdir}/package.conf.d/rts.conf %{buildroot}%{ghclibdir}/include >> ghc-base-devel.files
sed -i -e "s|^%{buildroot}||g" ghc-base-devel.files

# these are handled as alternatives
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
for i in hsc2hs runhaskell; do
  if [ -x %{buildroot}%{_bindir}/$i-ghc ]; then
    rm %{buildroot}%{_bindir}/$i
  else
    mv %{buildroot}%{_bindir}/$i{,-ghc}
  fi
  ln -s -f %{_sysconfdir}/alternatives/$i %{buildroot}%{_bindir}/$i
  touch %{buildroot}%{_sysconfdir}/alternatives/$i
done

%ghc_strip_dynlinked

find %{buildroot}%{ghclibdocdir} -name LICENSE -exec rm '{}' ';'

%check
# Actually, I took this from Jens Petersen's Fedora package
# stolen from ghc6/debian/rules:
# Do some very simple tests that the compiler actually works
rm -rf testghc
mkdir testghc
echo 'main = putStrLn "Foo"' > testghc/foo.hs
inplace/bin/ghc-stage2 testghc/foo.hs -o testghc/foo
[ "$(testghc/foo)" = "Foo" ]
# doesn't seem to work inplace:
#[ "$(inplace/bin/runghc testghc/foo.hs)" = "Foo" ]
rm testghc/*
echo 'main = putStrLn "Foo"' > testghc/foo.hs
inplace/bin/ghc-stage2 testghc/foo.hs -o testghc/foo -O2
[ "$(testghc/foo)" = "Foo" ]
rm testghc/*
%if %{undefined ghc_without_shared}
echo 'main = putStrLn "Foo"' > testghc/foo.hs
#inplace/bin/ghc-stage2 testghc/foo.hs -o testghc/foo -dynamic
#[ "$(testghc/foo)" = "Foo" ]
rm testghc/*
%endif

%post compiler
# Alas, GHC, Hugs and nhc all come with different set of tools in addition to
# a runFOO:
#
#   * GHC:  hsc2hs
#   * Hugs: hsc2hs, cpphs
#   * nhc:  cpphs
#
# Therefore it is currently not possible to use --slave below to form link
# groups under a single name 'runhaskell'. Either these tools should be
# disentangled from the Haskell implementations or all implementations should
# have the same set of tools. *sigh*
%{_sbindir}/update-alternatives --install %{_bindir}/runhaskell runhaskell %{_bindir}/runghc     500
%{_sbindir}/update-alternatives --install %{_bindir}/hsc2hs     hsc2hs     %{_bindir}/hsc2hs-ghc 500

%preun compiler
if test "$1" = 0; then
  %{_sbindir}/update-alternatives --remove runhaskell %{_bindir}/runghc
  %{_sbindir}/update-alternatives --remove hsc2hs     %{_bindir}/hsc2hs-ghc
fi

%files
%license LICENSE

%files compiler
%license LICENSE
%doc ANNOUNCE
%{_bindir}/ghc
%{_bindir}/ghc-%{version}
%{_bindir}/ghc-pkg
%{_bindir}/ghc-pkg-%{version}
%{_bindir}/ghci
%{_bindir}/ghci-%{version}
%{_bindir}/hp2ps
%{_bindir}/hpc
%{_bindir}/hsc2hs
%ghost %{_sysconfdir}/alternatives/hsc2hs
%{_bindir}/hsc2hs-ghc
%{_bindir}/runghc
%{_bindir}/runghc-%{version}
%{_bindir}/runhaskell
%ghost %{_sysconfdir}/alternatives/runhaskell
%{_bindir}/runhaskell-ghc
%dir %{ghclibdir}
%{ghclibdir}/settings
%dir %{ghclibdir}/bin
%{ghclibdir}/bin/ghc
%{ghclibdir}/bin/ghc-pkg
%{ghclibdir}/bin/ghc-iserv
%{ghclibdir}/bin/ghc-iserv-dyn
%{ghclibdir}/bin/ghc-iserv-prof
%{ghclibdir}/bin/hp2ps
%{ghclibdir}/bin/hpc
%{ghclibdir}/bin/hsc2hs
%ifnarch %{unregisterised_archs}
%{ghclibdir}/bin/ghc-split
%endif
%{ghclibdir}/ghc-usage.txt
%{ghclibdir}/ghci-usage.txt
%dir %{ghclibdir}/package.conf.d
%ghost %{ghclibdir}/package.conf.d/package.cache
%ghost %{ghclibdir}/package.conf.d/package.cache.lock
%{ghclibdir}/platformConstants
%{ghclibdir}/bin/runghc
%{ghclibdir}/template-hsc.h
%{ghclibdir}/bin/unlit
%dir %{_datadir}/doc/ghc-%{version}
%dir %{ghcdocbasedir}
%dir %{ghcdocbasedir}/libraries
%if %{undefined without_manual}
%{_mandir}/man1/ghc.*
%endif
%if %{undefined without_haddock}
%{_bindir}/haddock
%{_bindir}/haddock-ghc-%{version}
%{ghclibdir}/html
%{ghclibdir}/latex
%{ghclibdir}/bin/haddock
%if %{undefined without_manual}
%{ghcdocbasedir}/haddock
%{ghcdocbasedir}/users_guide
%endif
%{ghcdocbasedir}/libraries/gen_contents_index
%{ghcdocbasedir}/libraries/hslogo-16.png
%{ghcdocbasedir}/libraries/ocean.css
%{ghcdocbasedir}/libraries/prologue.txt
%{ghcdocbasedir}/libraries/synopsis.png
%{ghcdocbasedir}/index.html
%ghost %{ghcdocbasedir}/libraries/doc-index*.html
%ghost %{ghcdocbasedir}/libraries/haddock-util.js
%ghost %{ghcdocbasedir}/libraries/index*.html
%ghost %{ghcdocbasedir}/libraries/minus.gif
%ghost %{ghcdocbasedir}/libraries/plus.gif
%endif

%files libraries
%license LICENSE

%changelog
* Thu Apr 26 2018 mimi.vx@gmail.com
- fix BuildRequires for llvm
* Wed Apr 18 2018 mimi.vx@gmail.com
- use %%license macro as used by new ghc-rpm-macros
* Mon Dec 18 2017 ptrommler@icloud.com
- refresh ghc-pie.patch so it applies cleanly
* Sat Dec 16 2017 mimi.vx@gmail.com
- reintroduce ghc-pie.patch (pure upstreams don't work)
* Sat Dec  9 2017 ptrommler@icloud.com
- update to 8.2.2
- Several important correctness issues fixing potential runtime crashes
- A correctness issue leading to undefined behavior in some programs
  making use of STMa fixed
- A runtime system bug which may have manifested as a segmentation fault
  under low-memory conditions fixed
- ghc-pkg now works correctly ihn environments with misconfigured NFS mounts
- GHC can now produce position-independent executables
- Significantly improved type errors
- refresh reproducible-tmp-names.patch
- drop ghc-pie.patch fixed upstream
* Tue Oct 31 2017 ptrommler@icloud.com
- update to 8.2.1
- improved compiler performance
- reliable DWARF debugging information on x86_64 and i386
- aarch64: registerised through LLVM backend (experimental)
- optimized build for platforms with LLVM backend (arm, aarch64)
- improved performance on NUMA systems
- interface file determinism
- various language improvements
- update _constraints
  * ppc64le builds need less memory since 8.2.1
- drop support for ppc and s390
- drop ghc-no-madv-free.patch fixed upstream
- drop 0001-StgCmmPrim-Add-missing-write-barrier.patch
- refresh buildpath-abi-stability.patch
- refresh ghc-8.0.2-Cabal-dynlibdir.patch
- refresh ghc-pie.patch
- refresh reproducible-tmp-names.patch
- refresh 0001-PPC-Implement-Atomic-operations.patch
- refresh D4089.patch
* Tue Oct 17 2017 ptrommler@icloud.com
- add D4089.patch
  * fix GHCi issue on ppc64
  * see Haskell Trac #11262
* Fri Sep 22 2017 ptrommler@icloud.com
- add 0001-Use-__atomic-intrinsics-for-atomicread-write.patch
  * add missing memory barriers on atomic read/write ops
  * fixes upstream ticket #14244
- adjust comment for patch 32
  * the situation with upstream #12537 is improved but not
    solved. Patch 32, however, is correct. There are even more
    memory barriers missing elsewhere in the compiler.
* Sat Sep 16 2017 ptrommler@icloud.com
- add 0001-PPC-Implement-Atomic-operations.patch
  * fixes parallel programs on all PowerPC platforms
  * uptream ticket #12537
- refresh buildpath-abi-stability.patch
* Sun May 28 2017 mimi.vx@gmail.com
- make compatible with new upstream macros
- added patches for more stable abi:
  * buildpath-abi-stability.patch
  * reproducible-tmp-names.patch
* Sat May  6 2017 meissner@suse.com
- enable for global PIE support:
  - the compiler is built without PIE support due to the bootstrap
    libraries being non-PIE using BuildIgnore: gcc-PIE
  - the compiler itself builds -fPIC objects all the time,
    which should make all ghc compiled binaries be PIE.
- ghc-pie.patch: enable default -fPIC on Linux/x86_64
* Sun Jan 22 2017 peter.trommler@ohm-hochschule.de
- comment for patch 100
- refresh ghc-no-madv-free.patch with upstream patch
  * upstream fix for Haskell Trac #12865
  * Haskell Trac #12495 is a duplicate
* Sat Jan 21 2017 mimi.vx@gmail.com
- update to 8.0.2
- drop patches merged by upstream:
  * D2495.patch
- refreshed patches:
  * 0001-PPC-CodeGen-fix-lwa-instruction-generation.patch
  * 0001-StgCmmPrim-Add-missing-write-barrier.patch
  * ghc-no-madv-free.patch
- added ghc-8.0.2-Cabal-dynlibdir.patch by Jens Petersen simplifing
    haskell packaging
  + Interface files produced by GHC should now be deterministic ( boo#998972 )
  + A bug has been fixed that caused standalone derived Ix instances
    to fail for GADTs with exactly one constructor
  + Compatibility fixes recent Linux distributions.
* Fri Jan 20 2017 peter.trommler@ohm-hochschule.de
- drop D2844.patch
  * the patch causes more issues with parallel builds
- fixes boo#1020909
* Fri Dec 16 2016 peter.trommler@ohm-hochschule.de
- add D2844.patch
  * fix issues with parallel builds
* Fri Oct 14 2016 mimi.vx@gmail.com
- make compatible with new ghc-rpm-macros
* Wed Sep 28 2016 peter.trommler@ohm-hochschule.de
- update to 8.0.1
- drop patches fixed upstream:
  * drop atomic-cast.patch
  * drop cabal-show-detail-direct.patch
  * drop 0001-link-command-line-libs-to-temp-so.patch
  * drop 0001-implement-native-code-generator-for-ppc64.patch
  * drop ghc.git-b29f20.patch
  * drop u_terminfo_0402.patch
  * drop u_Cabal_update.patch
  * drop u_haskeline_update.patch
  * drop 0001-Fix-misspelled-WORDS_BIGENDIAN-macro.patch
  * drop D2214.patch
  * drop D2225.patch
- refresh 0001-StgCmmPrim-Add-missing-write-barrier.patch
- refresh 0001-PPC-CodeGen-fix-lwa-instruction-generation.patch
- add ghc-no-madv-free.patch to fix "unable to decommit memory:
  Invalid argument" errors GHC reports due to a misdetected
  MADV_FREE capability. The configure script sees the symbol define
  by glibc, but unfortunately this doesn't mean that the running
  kernel actually supports the feature, too. The upstream ticket
  https://ghc.haskell.org/trac/ghc/ticket/12495 has more details.
  Thanks to @psimons
- GHC produces debug information on x86 and x86_64
- aarch64 has LLVM backend (requires llvm-3.7)
- native code generator for powerpc64[le] (openSUSE contribution!)
- disable html doc on SLE, we don't have python-sphinx
  * Thanks @mimi_vx
* Tue Sep 27 2016 peter.trommler@ohm-hochschule.de
- add D2495.patch
  * missing memory barrier on PowerPC, ARM
- add 0001-StgCmmPrim-Add-missing-write-barrier.patch
  * another issing memory barrier on PowerPC, ARM
- add 0001-PPC-CodeGen-fix-lwa-instruction-generation.patch
  * fix bug in code generator
  * fixes build of ghc-zeromq4-haskell on powerpc64[le]
* Thu Aug 18 2016 mimi.vx@gmail.com
- fix boo#994268
* Tue May 17 2016 peter.trommler@ohm-hochschule.de
- add D2225.patch
  * backport of upstream patch accepted for ghc 8.0.1
  * fix SMP primitives on all powerpc archs
* Sat May 14 2016 peter.trommler@ohm-hochschule.de
- add D2214.patch
  * backport of upstream patch slated for ghc 8.0.2
  * fix issue in code PowerPC code generator (32 bit and 64 bit)
- add 0001-Fix-misspelled-WORDS_BIGENDIAN-macro.patch
  * backport of upstream fix slated for ghc 8.0.2
  * fix bytestring library on big-endian archs
  * fix wrong results in ghc-pureMD5 and others on big-endian
* Tue Apr 19 2016 mimi.vx@gmail.com
- update haskeline to 0.7.2.3
- refresh u_haskeline_update.patch
  * Fix hsc2hs-related warning on ghc-8
  * Fix the behavior of ctrl-W in the emacs bindings
  * Point to github instead of trac
* Tue Mar  8 2016 mimi.vx@gmail.com
- update Cabal to 1.22.8.0
- refresh u_Cabal_update.patch
  * Distribution.Simple.Setup: remove job cap
  * Check all object file suffixes for recompilation
  * Move source files under 'src/'.
* Wed Feb 17 2016 peter.trommler@ohm-hochschule.de
- limit parallel jobs to two on aarch64
  * aarch64 runs out of memory with too many parallel compiles
* Sun Feb 14 2016 peter.trommler@ohm-hochschule.de
- add missing C library dependency to terminfo devel package
* Sun Feb  7 2016 mimi.vx@gmail.com
- update haskeline to 0.7.2.2
- add u_haskeline_update.patch
  * canonicalize AMP instances to make the code more future proof
  * Generalize constraints for InputT instances
  * Bump upper bounds on base and transformers
  * Make Haskeline `-Wtabs` clean
* Tue Jan 26 2016 mimi.vx@gmail.com
- update Cabal to 1.22.7.0
- refresh u_Cabal_update.patch
  * Backport #3012 to the 1.22 branch
  * Add foldl' import
  * The Cabal part for fully gcc-like response files
* Tue Jan  5 2016 peter.trommler@ohm-hochschule.de
- update tarball to 7.10.3b
  * some documentation files were missing in the original
  7.10.3 tarball
- add 0001-link-command-line-libs-to-temp-so.patch
  * fix panic in GHCi when linking against C library specified
  as command line argument (-l<lib>)
  * currently under upstream review
  * fix Haskell trac #10458
* Mon Dec 28 2015 mimi.vx@gmail.com
- update Cabal to 1.22.6.0
- add u_Cabal_update.patch --  update of Cabal
  * Relax upper bound to allow upcoming binary-0.8
* Mon Dec 21 2015 mimi.vx@gmail.com
- update terminfo to 0.4.0.2
- drop remove-cur_term-usage.patch - merged by upstream
- add u_terminfo_0402.patch -- update of terminfo
* Mon Dec  7 2015 mimi.vx@gmail.com
- update Cabal to 1.22.5.0
  * Don't recompile C sources unless needed
  * Support Haddock response files.
  * Add frameworks when linking a dynamic library.
* Tue Dec  1 2015 mimi.vx@gmail.com
- use upstream variant of remove-cur_term-usage.patch
* Tue Oct  6 2015 peter.trommler@ohm-hochschule.de
- update to 7.10.3
- add cabal-show-detail-direct.patch -- Fix testsuites with large output.
    Debian patch. Thanks Joachim for suggesting it in Haskell #10870!
- add ghc.git-b29f20.patch
  * fixes upstream #7830
  * fix ghc 7.10.2 failing to bootstrap ghc head on ppc
  and perhaps ppc64 with some optimizations enabled
  * backport of my patch for upcoming ghc 8.0.1
* Mon Oct  5 2015 schwab@suse.de
- atomic-cast.patch: fix signature of atomic bultins
- ghc-7.8-arm-use-ld-gold.patch: remove obsolete patch
* Sat Oct  3 2015 sbahling@suse.com
- Remove ncurses6.patch - it's not so easy ;)
- Add remove-cur_term-usage.patch to remove the need to access the
  cur_term global which isn't available in the openSUSE ncurses6
  build.
* Sat Oct  3 2015 mimi.vx@gmail.com
- Add choice for libffi in openSUSE:Leap:42.1
* Sun Sep 20 2015 mimi.vx@gmail.com
- remove llvm from requires
- add ncurses6.patch to fix build with ncurses6, all thanks goes to
  Tomas Cech sleep_walker@opensuse.org
* Mon Aug 10 2015 peter.trommler@ohm-hochschule.de
- update to 7.10.2
  * type checker fixes
  * fixes for Aarch64 support
  * fix deadlock in runtime system when scheduling garbage collection
- 7.10.1 highlights
  * implement Applicative Monad Proposal
  * implement Burning Bridges Proposal
  * support for partial type signatures
  * reimplement integer-gmp
  * support plugins in type checker (experimental!)
- drop llvm-powerpc64-datalayout.patch
  * this patch was incomplete all along and now we have our native
  code generator
- drop ghc-cabal-unversion-docdir.patch
  * ghc-rpm-macros is following ghc's doc layout so no need to patch
- drop D349.patch
  * fixed upstream
- drop integer-gmp.patch
  * we do not support SLE11 anymore
- drop ghc-7.8.2-cgen-constify.patch
  * fixed upstream
- drop D560.patch
  * fixed upstream
- drop ghc-glibc-2.20_BSD_SOURCE.patch
  * fixed upstream
- drop ghc-arm64.patch
  * fixed upstream
- drop ghc-config.mk.in-Enable-SMP-and-GHCi-support-for-Aarch64.patch
  * fixed upstream
- refresh 0001-implement-native-code-generator-for-ppc64.patch
- disable ghc-7.8-arm-use-ld-gold.patch
  * not sure we need this, must be rebased if we do
* Fri Jul 17 2015 peter.trommler@ohm-hochschule.de
- add ghc-config.mk.in-Enable-SMP-and-GHCi-support-for-Aarch64.patch
  * enable SMP and GHCi on Aarch64
- add ghc-7.8-arm-use-ld-gold.patch
  * Aarch64 needs gold linker
* Fri May 29 2015 peter.trommler@ohm-hochschule.de
- refresh ghc-arm64.patch
- unconditionally apply ghc-arm64.patch
* Thu May 28 2015 peter.trommler@ohm-hochschule.de
- add backport of powerpc64le native code generator to
  0001-implement-native-code-generator-for-ppc64.patch
- refresh D349.patch
* Thu May 28 2015 ro@suse.de
- on s390/s390x use "make -j2" to stabilize abi hashes
  (see also redhat bug 1212374)
* Tue May 26 2015 mimi.vx@gmail.com
- disable llvm on arm64
* Thu May 21 2015 ro@suse.de
- re-diffed ghc-arm64.patch
* Thu May 21 2015 ro@suse.de
- add ghc-arm64.patch for aarch64
- add aarch64, s390, s390x to ExclusiveArch
* Tue Apr 14 2015 mimi.vx@gmail.com
- remove unneeded conditions
* Mon Apr 13 2015 mimi.vx@gmail.com
- chnage constraints to 12G for disk and 4G for ram
* Sun Mar 15 2015 peter.trommler@ohm-hochschule.de
- add ghc-glibc-2.20_BSD_SOURCE.patch
  * fixes build on unregisterised architectures (openSUSE: ppc64le)
* Mon Feb 23 2015 peter.trommler@ohm-hochschule.de
- drop ghc-cabal-unversion-docdir.patch
  * ghc-rpm-macros follows upstream ghc again
* Wed Feb  4 2015 mimi.vx@gmail.com
  + add ghc-glibc-2.20_BSD_SOURCE.patch from fedora
- updated to 7.8.4
  + removed D177.patch (in upstream)
  + removed D173.patch (in upstream)
  + removed ghc.git-e18525f.patch (in upstream)
  + refresh 0001-implement-native-code-generator-for-ppc64.patch
  * A critical bug in the LLVM backend which would cause the compiler to generate incorrect code has been fixed (issue #9439).
  * Several bugs in the code generator have been fixed for unregisterised platforms, such as 64bit PowerPC (issue #8819 and #8849).
  * A bug that could cause GHC's constructor specialization pass (enabled by default at -O2, or via -fspec-constr) to loop forever and consume large amounts of memory has been fixed (issue #8960).
  * A bug that would cause GHC to fail when attempting to determine GCC's version information in non-english locales has been fixed (issue #8825).
  * A minor bug that allowed GHC to seemingly import (but not use) private data constructors has been fixed (issue #9006).
  * A bug in the register allocator which would cause GHC to crash during compilation has been fixed (issue #9303).
  * A bug that caused the compiler to panic on some input C-- code has been fixed (issue #9329).
  * A few various minor deadlocks in the runtime system when using forkProcess have been fixed.
  * A bug which made blocked STM transactions non-interruptible has been fixed (issue #9379).
  * A bug in the compiler which broke pattern synonym imports across modules in Haddock has been fixed (issue #9417).
  * A minor bug in the code generator in which the popCnt16# did not zero-extend its result has been fixed (issue #9435).
  * A bug which caused the compiler to panic on pattern synonyms inside a class declaration has been fixed (issue #9705).
  * A bug in the typechecker revolving around un-saturated type family applications has been fixed (issue #9433).
  * Several bugs have been fixed causing problems with building GHC on ARM (issues #8951, #9620, #9336, and #9552).
  * A bug in the typechecker that could cause an infinite loop when using superclasses in a cycle has been fixed (issue #9415).
  * A bug causing corruption in signal handling with the single-threaded runtime system has been fixed (issue #9817).
  * A bug that could cause compiled programs to crash due to use of overlapping type families has been fixed (issue #9371).
  * A bug in the inliner that caused certain expressions within unboxed tuples to not be properly evaluated has been fixed (issue #9390).
  * A bug that caused the compiler to not always properly detect LLVM tools (particularly on Windows) has been fixed (issue #7143).
  * A bug that prevented GHC from deriving Generic1 instances for data families has been fixed (#9563).
  * A bug that caused type inference to infer the incorrect type in the presence of certain type families and constraints has been fixed (issue #9316).
* Tue Feb  3 2015 mimi.vx@gmail.com
- add constraints file
* Tue Feb  3 2015 mimi.vx@gmail.com
- remove dblatex dependency
* Mon Jan 12 2015 peter.trommler@ohm-hochschule.de
- add patch 0001-implement-native-code-generator-for-ppc64.patch
  * native code generation improved compilation speed
  * fewer errors in testsuite than with C back end
* Sat Dec 13 2014 peter.trommler@ohm-hochschule.de
- add patch D560.patch
  * fixes dynamic linking on ppc
  * see https://phabricator.haskell.org/D560
  * this is a back port of the upstream patch
* Wed Nov  5 2014 peter.trommler@ohm-hochschule.de
- add patch D349.patch
  * fix a crash with dynamic linking in GHCi when accessing the
  process environment
  * our patch has been submitted upstream
  * see https://phabricator.haskell.org/D349
* Sun Sep 28 2014 peter.trommler@ohm-hochschule.de
- ghc-rpm-macros use internal dependency generator now
  * simplifies spec file
* Sat Sep 20 2014 peter.trommler@ohm-hochschule.de
- fix alternatives handling
* Fri Sep 19 2014 peter.trommler@ohm-hochschule.de
- update to 7.8.3
  * needed for Haskell Platfoerm 2014.2.0.0
  * fixes bnc #726744
  * way smaller source tarball (windows binaries removed)
  * dynamic libraries, GHCi, and Template Haskell for ppc64 and ppc64le
- drop ghc-ppc64le.patch (fixed upstream)
- add integer-gmp.patch
  * build bundled libgmp on SLE 11 (system version is too old)
  * fixes build on x86_64
  * see upstream trac #8156
- add ghc-7.8.2-cgen-constify.patch
  * C backend (ppc64, ppc64le): generate 'const' strings
  * reduce size of table of contents (TOC)
- add D173.patch
  * fix C backend: generate literals of correct size
  * fixes lots of arithmetic failures and trac #8849
  * asked upstream to merge fix into 7.8.4
- add D177.patch
  * pass PIC flags to assembler
  * shared libraries on ppc still broken (trac #8024)
- add ghc.git-e18525f.patch
  * fix C backend: generate functions for cmm primitives
- drop ghc-use-system-libffi.patch (included upstream)
- drop ghc-suse-as-needed.patch (fixed upstream)
- drop Cabal-fix-dynamic-exec-for-TH.patch (fixed upstream)
- drop ghc-7.6.3-LlvmCodeGen-no-3.3-warning.patch (fixed upstream)
- drop ghc-avoid-empty-llvm-used-definitions.patch (fixed upstream)
- drop 0001-Fix-detection-of-library-for-shm-on-openSUSE.patch
  * our patch was included upstream
- drop 0001-Delete-spurious-comma-in-configure.ac.patch
  * our patch was included upstream
-drop ghc-fix-infinite-loop-big-endian.patch (fixed upstream
- refresh llvm-powerpc64-datalayout.patch
  * port to new LLVM backend
- refresh ghc-cabal-unversion-docdir.patch
  * include original Fedora patch for 7.8.2
* Tue Sep 16 2014 peter.trommler@ohm-hochschule.de
- bootstrap from ghc-bootstrap not ghc
  * remove BR loop ghc->ghc
* Thu Jul 31 2014 dimstar@opensuse.org
- Rename rpmlintrc to %%{name}-rpmlintrc.
  Follow the packaging guidelines.
* Sat May 10 2014 dvaleev@suse.com
- Enable ppc64le (ghc-ppc64le.patch)
* Mon Dec 16 2013 peter.trommler@ohm-hochschule.de
- use correct setting for unregisterised builds (ppc64)
- simplify build setup (generation of mk/build.mk)
* Mon Dec 16 2013 peter.trommler@ohm-hochschule.de
- don't BR llvm for now
- dblatex broken on older openSUSE
* Sun Dec 15 2013 peter.trommler@ohm-hochschule.de
- revert LLVM for ppc64 (segfaults during package install)
- fix setting up build.mk
- build perf for all archs
* Sat Dec 14 2013 peter.trommler@ohm-hochschule.de
- Add llvm-powerpc64-datalayout.patch
  * fix LLVM backend for powerpc64
- build and test LLVM backend on powerpc64
* Fri Dec 13 2013 peter.trommler@ohm-hochschule.de
- Add cabal-unversion-docdir.patch
  * ghc-rpm-macros don't include versions in package docdirs
  starting with version 1.0
- use standard docdir for ghc
- package pdf and ps manuals
* Mon Oct 28 2013 peter.trommler@ohm-hochschule.de
- Add ghc-fix-infinite-loop-big-endian.patch: Fix Haskell trac
  [#8134] on ppc64.
- Enable threaded runtime on ppc64
* Tue Sep 24 2013 peter.trommler@ohm-hochschule.de
- Add 0001-Fix-detection-of-library-for-shm-on-openSUSE.patch:
  Fix broken autoconf test for shm_* and librt. Haskell trac #8350
- Add 0001-Delete-spurious-comma-in-configure.ac.patch:
  Fix test for setitimer. Haskell trac #8352
* Tue Sep 24 2013 peter.trommler@ohm-hochschule.de
- set up build.mk with configuration for ppc64
  * explicitly disable features that are not supported on ppc64
* Mon Sep 23 2013 peter.trommler@ohm-hochschule.de
- add BR binutils-devel for bfd.h and libiberty
* Mon Sep 23 2013 peter.trommler@ohm-hochschule.de
- add BR libelf-devel for nlist.h
* Tue Sep 10 2013 peter.trommler@ohm-hochschule.de
- Patches for llvm 3.3.
  * Add ghc-7.6.3-LlvmCodeGen-no-3.3-warning.patch: Silence warning
  about llvm too new
  * Add ghc-avoid-empty-llvm-used-definitions.patch: Fix llvm code
  generator. Backported patch for ghc 7.7 (cf Haskell trac #7996)
- explicitly configure gcc location in bootstrap builds too
- allow ppc builds (ppc64 build gets stuck)
* Fri Sep  6 2013 peter.trommler@ohm-hochschule.de
- include BuildFlavour definitions in build.mk
* Tue Sep  3 2013 peter.trommler@ohm-hochschule.de
- build optimized compiler (BuildFlavour = perf)
- bring back Fedora's Template Haskell patch
- add Haskell trac ticket number to glibc-locale comment
* Tue Jul 16 2013 peter.trommler@ohm-hochschule.de
- add comment to explain why glibc-locale is required by
  ghc-compiler
* Fri May 17 2013 peter.trommler@ohm-hochschule.de
- glibc-locale required by ghc-pkg
* Fri May  3 2013 peter.trommler@ohm-hochschule.de
- update to 7.6.3 from upstream
- part of Haskell Platform 2013.2
- new languages features (polymorphic kinds, ...)
- do compiler upgrade in one submit request by bootstrapping
  ghc if necessary and use that ghc to selfbootstrap new
  ghc
- replaced ghc-use-system-libffi.patch with new patch for
  Haskell trac #5743 (add configure option to use system libffi)
- drop Cabal-fix-dynamic-exec-for-TH.patch: Fixed upstream
- drop ghc-6.12.1-gen_contents_index-haddock-path.patch which used
  system provided haddock and that causes trouble when bootstrapping
- drop ghc-gen_contents_index-type-level.patch: fixed upstream
- drop patch ghc-fix-undefined-openpty.patch: Fixed upstream
- drop patch 0001-Add-missing-flag-for-respecting-EXTRA_LIBDIR.patch:
  Fixed upstream
- port to new ghc-rpm-macros
* Fri Jan 11 2013 peter.trommler@ohm-hochschule.de
- enable color and links in documentation
* Mon Dec  3 2012 peter.trommler@ohm-hochschule.de
- try to work around factory-auto still thinking we need
  to wait for BRs even when those are in a comment
* Wed Nov 28 2012 peter.trommler@ohm-hochschule.de
- help factory-auto by commenting out currently unneeded BRs
* Tue Nov 13 2012 peter.trommler@ohm-hochschule.de
- selfbootstrap ghc 7.4.2
* Mon Nov 12 2012 peter.trommler@ohm-hochschule.de
- remove binary distributions after bootstrap in Factory
* Thu Nov  8 2012 peter.trommler@ohm-hochschule.de
- Update to version 7.4.2 from upstream
  * Required by Haskell Platform 2012.4.0.0
  * Fixes for ghc and ghci
* Thu Nov  8 2012 peter.trommler@ohm-hochschule.de
- add ExclusiveArch tag
* Tue Nov  6 2012 peter.trommler@ohm-hochschule.de
- generate debug packages for Factory
* Sun Oct 14 2012 peter.trommler@ohm-hochschule.de
- do not warn about metapackage ghc containing no binary
* Sat Oct 13 2012 peter.trommler@ohm-hochschule.de
- fix cyclic dependency to ghc (libraries reqire ghc-compiler)
* Fri Oct 12 2012 peter.trommler@ohm-hochschule.de
- do not override automatic dependency generation
  * needs ghc-pkg which we won't have in Factory yet
* Fri Oct 12 2012 peter.trommler@ohm-hochschule.de
- prepare for bootstrap in Factory
  * add binary distribution to spec file
  * change build to use ghc provided by binary distribution
* Tue Jul 31 2012 peter.trommler@ohm-hochschule.de
- back ported two patches for Haskell trac #7062
  * fix openpty undefined symbol
  * fix extra libraries not on linker path
* Sat Jul 28 2012 peter.trommler@ohm-hochschule.de
- fix ghc-suse-as-needed.patch
  * add --disable-new-dtags to linker flags. Adding RUNPATH to shared
  libraries breaks linking. To fix that ghc's libraries need to set
  their own RUNPATHs which they currently don't.
  * fixes Haskell #7062
* Mon Jun 25 2012 peter.trommler@ohm-hochschule.de
- use ghc_lib_subpackage instead of ghc_binlib_package (ghc-rpm-macros 0.95.5.1)
- add simple checks to %%check section
- sort BuildRequires somewhat
* Sun Jun 24 2012 peter.trommler@ohm-hochschule.de
- remove perl boot comment
- rebuild after project conf fix for hscolour (keep deepseq)
* Wed Jun 20 2012 peter.trommler@ohm-hochschule.de
- enable hscolour after bootstrap
* Wed Jun  6 2012 peter.trommler@ohm-hochschule.de
- disable bootstrapping for devel:languagaes:haskell
* Wed Jun  6 2012 peter.trommler@ohm-hochschule.de
- set bootstrapping for bootstrap in devel:languages:haskell
* Mon Jun  4 2012 peter.trommler@ohm-hochschule.de
- add autoreconf required by suse as-needed patch
* Mon Jun  4 2012 peter.trommler@ohm-hochschule.de
- selfbootstraping
- disable perl boot, might undo libffi patch
* Mon Jun  4 2012 peter.trommler@ohm-hochschule.de
- upgrade to 7.4.1 from upstream for Haskell Platform 2012.2.0.0
- drop Cabal-option-executable-dynamic.patch (fixed in upstream)
- add ghc-suse-as-needed.patch
- add Cabal-fix-dynamic-exec-for-TH.patch
- add ghc-gen_contents_index-type-level.patch
- bootstrapping
* Sun Jun  3 2012 peter.trommler@ohm-hochschule.de
- apply patch 2
- use perl boot to autoreconf all subdirectories
* Mon May 28 2012 peter.trommler@ohm-hochschule.de
- added LICENSE to library and base package
- should probably be ignored in rpmlintrc
* Mon May 28 2012 peter.trommler@ohm-hochschule.de
- follow Fedora packaging:
- package compiler in ghc-compiler
- meta package for all libraries
- ghc became meta package for everything
* Sat May 26 2012 peter.trommler@ohm-hochschule.de
- deleted extra BR after project configuration fix
* Fri May 25 2012 peter.trommler@ohm-hochschule.de
- remove minimum version requirement for gmp-devel
* Sat May 19 2012 peter.trommler@ohm-hochschule.de
- don't pack manual page when without_manual is set
* Sat May 19 2012 peter.trommler@ohm-hochschule.de
- temporarily disable manual to work around broken texlive
* Thu May 17 2012 peter.trommler@ohm-hochschule.de
- clean up BuildRequires (one per line)
- force gmp-devel >= 5 to get rid of libgmp.so.3 in Factory
* Mon Mar 12 2012 peter.trommler@ohm-hochschule.de
- enabled hscolour
* Fri Feb  3 2012 peter.trommler@ohm-hochschule.de
- selfbootstrapping
* Fri Feb  3 2012 peter.trommler@ohm-hochschule.de
- disable dependecy generator during bootstrap
* Thu Feb  2 2012 peter.trommler@ohm-hochschule.de
- bootstrap SLE11-SP1
* Mon Jan 23 2012 peter.trommler@ohm-hochschule.de
- provide ghc-compiler = %%{version}
* Mon Jan 23 2012 peter.trommler@ohm-hochschule.de
- package HSffi.o on 11.3
* Sun Jan 22 2012 peter.trommler@ohm-hochschule.de
- done bootstrapping
* Sun Jan 22 2012 peter.trommler@ohm-hochschule.de
- Move documentation to new place
- Fix douple packaging
* Mon Jan 16 2012 peter.trommler@ohm-hochschule.de
- Added haddock patch
- Fixed many file packaged twice issues
* Wed Jan  4 2012 peter.trommler@ohm-hochschule.de
- Enabled hscolour
- Prepared for libffi patch (needs fix fo bnc#711489)
* Thu Dec 29 2011 peter.trommler@ohm-hochschule.de
- Lowered ghc BR to 6.10
* Wed Dec 28 2011 peter.trommler@ohm-hochschule.de
- Added Cabal patch (required for ghc-rpm-macros)
* Wed Dec 28 2011 peter.trommler@ohm-hochschule.de
- unset bootstrapping
- additional BR that should not be required
* Tue Dec 27 2011 peter.trommler@ohm-hochschule.de
- Fixed versions and names in libraries
- Fixed files section
* Thu Dec 22 2011 peter.trommler@ohm-hochschule.de
- Start version 7.0.4
